@@ -26,6 +26,12 @@ featnames <- function(x) {
     UseMethod("featnames")
 }
 
+#' @export
+#' @noRd
+featnames.NULL <- function(x) {
+    NULL
+}
+
 #' @export
 #' @noRd
 featnames.dfm <- function(x) {
@@ -48,6 +54,12 @@ docnames.dfm <- function(x) {
     rownames(x)
 }
 
+#' @noRd
+#' @export
+docnames.NULL <- function(x) {
+    NULL
+}
+
 #' coercion and checking functions for dfm objects
 #' 
 #' Check for a dfm, or convert
