@@ -57,15 +57,38 @@ tokens_lookup <- function(x, dictionary, levels = 1:5,
                           valuetype = c("glob", "regex", "fixed"), 
                           concatenator = ' ',
                           case_insensitive = TRUE,
-                          capkeys = FALSE,
+                          capkeys = !exclusive,
                           exclusive = TRUE,
+#                          overlap = FALSE,
                           multiword = TRUE,
                           verbose = FALSE) {
+    UseMethod("tokens_lookup")    
+}
+
+#' @noRd
+#' @export
+tokens_lookup.tokens <- function(x, dictionary, levels = 1:5,
+                          valuetype = c("glob", "regex", "fixed"), 
+                          concatenator = ' ',
+                          case_insensitive = TRUE,
+                          capkeys = !exclusive,
+                          exclusive = TRUE,
+#                          overlap = FALSE,
+                          multiword = TRUE,
+                          verbose = FALSE) {
+ 
+    overlap <- FALSE
+    
+    if (!is.tokens(x))
+        stop("x must be a tokens object")
+    
+    if (!is.dictionary(dictionary))
+        stop("dictionary must be a dictionary object")
     
     names_org <- names(x)
     attrs_org <- attributes(x)
     concatenator_dict <- attr(dictionary, 'concatenator')
-    dictionary <- dictionary_flatten(dictionary, levels)
+    dictionary <- flatten_dictionary(dictionary, levels)
     valuetype <- match.arg(valuetype)
     
     # Generate all combinations of type IDs
@@ -75,7 +98,9 @@ tokens_lookup <- function(x, dictionary, levels = 1:5,
     
     index <- index_regex(types, valuetype, case_insensitive) # index types before the loop
     if (verbose) 
-        message('Registering ', length(unlist(dictionary)), ' entries in the dictionary...');
+        catm("applying a dictionary consisting of ", length(dictionary), " key", 
+             ifelse(length(dictionary) > 1, "s", ""), "\n", sep="")
+    
     for (h in 1:length(dictionary)) {
         entries <- dictionary[[h]]
         
@@ -94,22 +119,22 @@ tokens_lookup <- function(x, dictionary, levels = 1:5,
         entries_id <- c(entries_id, entries_temp)
         keys_id <- c(keys_id, rep(h, length(entries_temp)))
     }
-    if (verbose) 
-        message('Searching ', length(entries_id), ' types of features...')
+    # if (verbose) 
+    #     message('Searching ', length(entries_id), ' types of features...')
     
-    if(exclusive){
-        x <- qatd_cpp_tokens_lookup(x, entries_id, keys_id)
-    }else{
-        x <- qatd_cpp_tokens_replace(x, entries_id, keys_id + length(types))
+    if (exclusive) {
+        x <- qatd_cpp_tokens_lookup(x, entries_id, keys_id, overlap)
+    } else {
+        x <- qatd_cpp_tokens_match(x, entries_id, keys_id + length(types), FALSE)
     }
     attributes(x) <- attrs_org
-    if(exclusive){
+    if (exclusive) {
         if (capkeys) {
             types(x) <- char_toupper(names(dictionary))
         } else {
             types(x) <- names(dictionary)
         }
-    }else{
+    } else {
         if (capkeys) {
             types(x) <- c(types, char_toupper(names(dictionary)))
         } else {
