@@ -1,6 +1,6 @@
 .onAttach <- function(...) {
     packageStartupMessage("quanteda version ", as.character(utils::packageVersion("quanteda")))
     threads <- RcppParallel::defaultNumThreads()
-    packageStartupMessage("Use ", threads - 1, " of ", threads, " cores in parallel computing")
+    packageStartupMessage("Using ", threads - 1, " of ", threads, " cores for parallel computing")
     RcppParallel::setThreadOptions(threads - 1)
 }
